.. currentmodule:: sardana.pool.poolcontainer

:mod:`~sardana.pool.poolcontainer`
======================================

.. automodule:: sardana.pool.poolcontainer

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolContainer`

PoolContainer
-------------------

.. inheritance-diagram:: PoolContainer
    :parts: 1
    
.. autoclass:: PoolContainer
    :show-inheritance:
    :members:
    :undoc-members:
